library(ggplot2)
library(reshape2)
library(grid)
library(scales)

#setwd("/home/salvo/ETH/dphpc17/recitations/liblsb")
liblsb_path <- "/home/salvo/ETH/liblsb/R/"
source(paste(liblsb_path, "utils.R", sep=""))
source(paste(liblsb_path, "stats.R", sep=""))
source(paste(liblsb_path, "aes.R", sep=""))

data.all <- ReadAllFilesInDir.Aggregate(dir.path="data/", col=c("rank", "size", "run", "id", "time", "overhead", "PAPI_TOT_INS", "PAPI_L1_DM"))
data.run <- CalculateDataSummary(data=data.all, measurevar="time", groupvars = c("run", "size", "id"), conf.interval = .95, quantile.interval = .95)
data.summ <- CalculateDataSummary(data=data.run, measurevar="max", groupvars = c("size", "id"), conf.interval = .95, quantile.interval = .95)

lbl=c("Computation", "Communication")
plot_comp <- ggplot(data=data.summ, aes(x=size, y=median, color=factor(id), shape=factor(id), ymin=CI.NNorm.high, ymax=CI.NNorm.low)) +
  geom_point() +
  geom_line() +
  geom_errorbar()+
  theme_bw(20) +
  scale_color_discrete(name="", labels=lbl) +
  scale_shape_discrete(name="", labels=lbl) +
  scale_x_continuous(trans="log2", name="Processing Elements") +
  scale_y_continuous(name="Time (us)") +
  theme(legend.key = element_rect(fill = "transparent", colour = "transparent"), legend.background = element_rect(fill="transparent", colour="transparent"))  
plot_comp
PrintGGPlotOnPDF(plot_comp, "plot_comparison.pdf", 10, 5)



data.c32_comp <- subset(data.all, size==32 & id==0)
plot_c32_comp <- ggplot(data=data.c32_comp, aes(x=factor(rank), y=time))+
  geom_boxplot() +
  #geom_violin() +
  scale_x_discrete(name="Rank") +
  scale_y_continuous(name="Time (us)")
plot_c32_comp
PrintGGPlotOnPDF(plot_c32_comp, "plot_per_rank_32.pdf", 10, 5)


